% Constructor.
% This class represents material properties of deformable linearly elastic isotropic materials.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options:
% required fields
%     E=Young's modulus
%     nu=Poisson ratio
% optional fields
%     alpha = coefficient of thermal expansion
%
function retobj = property_linel_iso(varargin)
    class_name='property_linel_iso';
    if (nargin == 0)
        parent=property;
        self.E = 1.0;
        self.nu = 0.0;
        self.alpha = 0.0;
        retobj = class(self,class_name, parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options =varargin{1};
            parent=property(options);
            self.E = options.E;
            self.nu = 0;
            if isfield(options,'nu')
                self.nu = options.nu;
                if (self.nu < 0)
                    error('Negative Poisson ratio!');
                elseif (self.nu >= 0.5)
                    error('Incompressible material!');
                end
            end
            self.alpha = 0.0;
            if isfield(options,'alpha')
                self.alpha= options.alpha;
            end
            retobj = class(self,class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end