% Thick plate, small displacement, small strain analysis
disp('Thick plate, small displacement, small strain analysis');

% Parameters:
E=1e3;
nu=0.2;
graphics =1; % graphic output
scale = 10;

% Mesh
n=2;
tic; % for n= 10, that is almost 14,000 equations, we need about half a minute
[fens,gcells] = block (4,4,0.5,2*n,2*n,n);
% Material
prop = property_linel_iso (struct('E',E,'nu',nu));
mater = mater_defor_ss_linel_triax (struct('property',prop));
% Finite element block
feb = feblock_defor_ss (struct('mater',mater,'gcells',gcells,...
    'integration_rule',gauss_rule(3, 2)));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
% Define the displacement field
u   = 0*geom; % zero out
% Apply EBC's
ebc_fenids=fenode_select (fens,struct('box',[-10 10 4 4 -10 10]));
ebc_prescribed=ebc_fenids*0+1;
ebc_comp=[];
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
u   = apply_ebc (u);
% Number equations
u   = numbereqns (u);
% Assemble the system matrix
ems = stiffness(feb, geom, u);
K = start (sparse_sysmat, get(u, 'neqns'));
K = assemble (K, ems);
% Load
F = start (sysvec, get(u, 'neqns'));
corn=fenode_select (fens,struct('box',[4 4 0 0 1/2 1/2]));
evs = loads(nodal_load(struct ('id',corn,'dir',[3],'magn',[-1])), u);
F = assemble (F, evs);
% Solve
a = get(K,'mat');
b = get(F,'vec');
x = a\b;
u = scatter_sysvec(u, x);
toc

if graphics
    gv=graphic_viewer;
    gv=reset (gv,[]);
    for i=1:length (gcells)
        draw(gcells(i), gv, struct ('x',geom,'u', scale*u, 'facecolor','none'));
    end
    max_sigma_xx=inspect_integration_points(feb, geom, u, [], (1:length (gcells)), struct ('output',['Cauchy']),...
        inline('max(out(1), inspector_data)','inspector_data','out','xyz','pc'),...
        -Inf);
    min_sigma_yy=inspect_integration_points(feb, geom, u, [], (1:length (gcells)), struct ('output',['Cauchy']),...
        inline('min(out(1), inspector_data)','inspector_data','out','xyz','pc'),...
        Inf);
    dcm=data_colormap(struct ('range',[min_sigma_yy,max_sigma_xx], 'colormap',jet));
    draw_integration_points(feb,gv,struct ('x',geom,'u',scale*u, 'scale',0.005,'component',1,'data_cmap', dcm));
end
