% The mouse 'up' function switches between rotating and not
% rotating the figure.  The mouse move function, when enabled,
% rotates the figure in the direction of mouse movement
% within the figure.
% %

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Licence:            GNU GPL, no implied or express warranties
%Created:  10/1995 - Eric Soroos
%Modified: 02/2002 - Darren.Weber@flinders.edu.au
%                  - integrated all commands into one function .m file
%                  - changed rotation to mouse direction rather than
%                    anti-mouse direction and during mouse up rather
%                    than mouse down.
%                  - changed target to the 'view' property of gca
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function graphic_viewer_mouse_rotate(command)

if ~exist('command','var'), command = 'init'; end

switch command,

    case 'init',

        set(gcf,'WindowButtonUpFcn','graphic_viewer_mouse_rotate(''up''); ');

        H.exit  = uicontrol('Parent',gcf,'Style','pushbutton',...
            'Units','Normalized','Position',[.9 .0 .1 .05],...
            'String','Done','Value',0,...
            'TooltipString','Exit figure rotation.',...
            'Callback',strcat('H = get(gcbf,''userdata'');',...
            'delete(H.exit); ',...
            'set(gcbf,''WindowButtonMotionFcn'',[]); ',...
            'set(gcbf,''WindowButtonDownFcn'',[]); ',...
            'set(gcbf,''WindowButtonUpFcn'',[]); ',...
            'clear H;'));

        set(gcf,'userdata',H);

        % Add gui controls with tooltips for help

    case 'up',

        %This switches between rotation and no rotation.
        %On a button press, it checks whether the motion function is
        %set - if yes, it clears it, otherwise it adds it.
        if isempty(get(gcbf,'WindowButtonMotionFcn')),
            set(gcbf,'WindowButtonMotionFcn','graphic_viewer_mouse_rotate(''rotate'');');
        else
            pos.current = get(gca,'View');
            set(gcbf,'WindowButtonMotionFcn',[]);
        end

    case 'rotate',

        % rotates the figure in the direction of mouse movement
        % i.e. in the center, 0 altitude, 0 azimuth. Going up and down
        % changes the altitude, left and right changes the azimuth.
        pos.fig = get(gcf,'position');
        pos.mouse = get(0,'pointerlocation');
        pos.relative = -1 * (((pos.mouse(1:2) - pos.fig(1:2))./ pos.fig(3:4))-.5).*[360,190];
        set(gca,'View',pos.relative);

        H = get(gcf,'userdata');
        

    otherwise,

end

return;


